"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var moment = require("moment");
var draft_1 = require("./draft");
var headersBuilder_1 = require("./headersBuilder");
var DraftStoreClient = /** @class */ (function () {
    function DraftStoreClient(endpointURL, serviceAuthToken, request) {
        this.endpointURL = endpointURL;
        this.serviceAuthToken = serviceAuthToken;
        this.request = request;
    }
    DraftStoreClient.prototype.find = function (query, userAuthToken, deserializationFn, secrets) {
        var type = query.type, qs = __rest(query, ["type"]);
        var endpointURL = this.endpointURL + "/drafts";
        return this.request
            .get(endpointURL, {
            qs: qs,
            headers: headersBuilder_1.HeadersBuilder.buildHeaders(userAuthToken, this.serviceAuthToken, secrets)
        })
            .then(function (response) {
            return response.data
                .filter(function (draft) { return type ? draft.type === type : true; })
                .map(function (draft) {
                return new draft_1.Draft(draft.id, draft.type, deserializationFn(draft.document), moment(draft.created), moment(draft.updated));
            });
        });
    };
    DraftStoreClient.prototype.save = function (draft, userAuthToken, secrets) {
        var options = {
            headers: headersBuilder_1.HeadersBuilder.buildHeaders(userAuthToken, this.serviceAuthToken, secrets),
            body: {
                type: draft.type,
                document: draft.document
            }
        };
        var endpointURL = this.endpointURL + "/drafts";
        if (!draft.id) {
            return this.request.post(endpointURL, options);
        }
        else {
            return this.request.put(endpointURL + "/" + draft.id, options);
        }
    };
    DraftStoreClient.prototype.delete = function (draftId, userAuthToken) {
        if (!draftId) {
            throw new Error('Draft does not have an ID - it cannot be deleted');
        }
        var endpointURL = this.endpointURL + "/drafts";
        return this.request.delete(endpointURL + "/" + draftId, {
            headers: headersBuilder_1.HeadersBuilder.buildHeaders(userAuthToken, this.serviceAuthToken)
        });
    };
    return DraftStoreClient;
}());
exports.DraftStoreClient = DraftStoreClient;
